const fs = require('fs');
const path = require('path');
const express = require('express');

const sourcePath = path.join(__dirname, '../sources/log.json');

// 导入工具方法
const { setHeader, setJSONResponse } = require('../utils/res');
const getIp = require('../utils/getIp');

const router = express.Router();

// 获取所有日志
router.get('/', (req, res) => {
	setHeader(res, 'Access-Control-Allow-Origin', '*');
	fs.readFile(sourcePath, (err, data) => {
		if (err) {
			setJSONResponse(res, { ret: -1 });
		} else {
			const logs = JSON.parse(data.toString());
			setJSONResponse(res, { ret: 0, data: logs });
		}
	});
});

// 获取特特定类型的所有日志
router.get('/:type', (req, res) => {
	setHeader(res, 'Access-Control-Allow-Origin', '*');
	fs.readFile(sourcePath, (err, data) => {
		if (err) {
			setJSONResponse(res, { ret: -1 });
		} else {
			const { type } = req.params;
			let logs = JSON.parse(data.toString());
			if (type) {
				logs = logs.filter(log => {
					return log.type === type;
				});
			}
			setJSONResponse(res, { ret: 0, data: logs });
		}
	});
});

// 写入特定类型的日志
router.get('/hello/:type', (req, res) => {
	setHeader(res, 'Access-Control-Allow-Origin', '*');
	fs.readFile(sourcePath, (err, data) => {
		if (err) {
			setJSONResponse(res, { ret: -1 });
		} else {
			const logs = JSON.parse(data.toString());

			const { headers, params } = req;
			const { type } = params;

			const logItem = {
				ip: getIp(req),
				time: Date.now(),
				userAgent: headers['user-agent'],
				language: headers['accept-language'],
				type
			};

			logs.push(logItem);

			fs.writeFile(sourcePath, JSON.stringify(logs), (err) =>  {
				if (err) {
					setJSONResponse(res, { ret: -1 });
				} else {
					setJSONResponse(res, { ret: 0 });
				}
			});
		}
	});
});

module.exports = router;